.. timemarker documentation master file, created by
   sphinx-quickstart on Mon Oct 30 22:24:39 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

timemarker documentation
========================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   use.rst
   api.rst



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
